package de.szut.lf8_starter.project.action.employee;

import de.szut.lf8_starter.project.ProjectEntity;
import de.szut.lf8_starter.project.ProjectService;
import org.springframework.http.*;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.client.RestTemplate;

import java.util.Optional;

@RestController
public class AddEmployeeToProjectAction {
    private final ProjectService projectService;
    private final RestTemplate restTemplate;

    public AddEmployeeToProjectAction(ProjectService projectService, RestTemplate restTemplate) {
        this.projectService = projectService;
        this.restTemplate = restTemplate;
    }


    @PostMapping("/projects/{projectId}/employees/{employeeId}")
    public ResponseEntity<Object> create(
            @PathVariable Long projectId,
            @PathVariable Long employeeId,
            @RequestHeader("Authorization") String accessToken
    ) {
        Optional<ProjectEntity> project = this.projectService.findById(projectId);

        if (project.isEmpty()) {
            return new ResponseEntity<>(HttpStatus.NOT_FOUND);
        }

        HttpHeaders headers = new HttpHeaders();
        headers.setBearerAuth(accessToken.replace("Bearer ", ""));

        HttpEntity<String> requestEntity = new HttpEntity<>(headers);

        String url = "https://employee.szut.dev/employees/" + employeeId;
        ResponseEntity<String> response = restTemplate.exchange(url, HttpMethod.GET, requestEntity, String.class);

        System.out.println("Employee Data: " + response.getBody());

        return new ResponseEntity<>(HttpStatus.NO_CONTENT);
    }
}
